==> kinobi-0.1.0.tgz: package/src/visitors/aggregators/GetNodeInlineStringVisitor.ts <==
import type * as nodes from '../../nodes';
import { Visitor } from '../Visitor';

const ROOT_PREFIX = 'R';
const PROGRAM_PREFIX = 'P';
const ACCOUNT_PREFIX = 'A';
const INSTRUCTION_PREFIX = 'I';
const TYPE_PREFIX = 'T';
const ERROR_PREFIX = 'E';

export class GetNodeInlineStringVisitor implements Visitor<string> {
  visitRoot(root: nodes.RootNode): string {
    const children = root.programs.map((program) => program.accept(this));
    return `${ROOT_PREFIX}(${children.join(',')})`;
  }

  visitProgram(program: nodes.ProgramNode): string {
    const children = [
      ...program.accounts.map((account) => account.accept(this)),
      ...program.instructionsWithSubs.map((ix) => ix.accept(this)),
      ...program.definedTypes.map((type) => type.accept(this)),
      ...program.errors.map((type) => type.accept(this)),
    ];
    return `${PROGRAM_PREFIX}[${program.name}](${children.join(',')})`;
  }

  visitAccount(account: nodes.AccountNode): string {
    const child = account.type.accept(this);
    return `${ACCOUNT_PREFIX}[${account.name}](${child})`;
  }

  visitInstruction(instruction: nodes.InstructionNode): string {
    const accounts = instruction.accounts.map((account) => account.name);
    const args = instruction.args.accept(this);
    return (
      `${INSTRUCTION_PREFIX}[${instruction.name}](` +
      `accounts:(${accounts.join(',')}),` +
      `args:(${args})` +
      `)`
    );
  }

  visitDefinedType(definedType: nodes.DefinedTypeNode): string {
    const child = definedType.type.accept(this);
    return `${TYPE_PREFIX}[${definedType.name}](${child})`;
  }

  visitError(error: nodes.ErrorNode): string {
    return `${ERROR_PREFIX}[${error.name}]`;
  }

  visitTypeArray(typeArray: nodes.TypeArrayNode): string {
    const child = typeArray.itemType.accept(this);
    return `array(${typeArray.size};${child})`;
  }

  visitTypeDefinedLink(typeDefinedLink: nodes.TypeDefinedLinkNode): string {
    return `link(${typeDefinedLink.definedType})`;
  }

  visitTypeEnum(typeEnum: nodes.TypeEnumNode): string {
    const children = typeEnum.variants.map((variant) => variant.accept(this));
    return `enum[${typeEnum.name}](${children.join(',')})`;
  }

  visitTypeEnumEmptyVariant(
    typeEnumEmptyVariant: nodes.TypeEnumEmptyVariantNode
  ): string {
    return typeEnumEmptyVariant.name;
  }

  visitTypeEnumStructVariant(
    typeEnumStructVariant: nodes.TypeEnumStructVariantNode
  ): string {
    const child = typeEnumStructVariant.struct.accept(this);
    return `${typeEnumStructVariant.name}:${child}`;
  }

  visitTypeEnumTupleVariant(
    typeEnumTupleVariant: nodes.TypeEnumTupleVariantNode
  ): string {
    const child = typeEnumTupleVariant.tuple.accept(this);
    return `${typeEnumTupleVariant.name}:${child}`;
  }

  visitTypeLeaf(typeLeaf: nodes.TypeLeafNode): string {
    return typeLeaf.type;
  }

  visitTypeLeafWrapper(typeLeafWrapper: nodes.TypeLeafWrapperNode): string {
    const child = typeLeafWrapper.leaf.accept(this);
    const { wrapper } = typeLeafWrapper;
    switch (wrapper.kind) {
      case 'DateTime':
        return `DateTime(${child})`;
      case 'Amount':
        return `Amount(${child},${wrapper.identifier},${wrapper.decimals})`;
      default:
        return child;
    }
  }

  visitTypeMap(typeMap: nodes.TypeMapNode): string {
    const key = typeMap.keyType.accept(this);
    const value = typeMap.valueType.accept(this);
    return `map(${key},${value})`;
  }

  visitTypeOption(typeOption: nodes.TypeOptionNode): string {
    const child = typeOption.type.accept(this);
    return `option(${child})`;
  }

  visitTypeSet(typeSet: nodes.TypeSetNode): string {
    const child = typeSet.type.accept(this);
    return `set(${child})`;
  }

  visitTypeStruct(typeStruct: nodes.TypeStructNode): string {
    const children = typeStruct.fields.map((field) => field.accept(this));
    return `struct[${typeStruct.name}](${children.join(',')})`;
  }

  visitTypeStructField(typeStructField: nodes.TypeStructFieldNode): string {
    const child = typeStructField.type.accept(this);
    return `${typeStructField.name}:${child}`;
  }

  visitTypeTuple(typeTuple: nodes.TypeTupleNode): string {
    const children = typeTuple.itemTypes.map((itemType) =>
      itemType.accept(this)
    );
    return `tuple(${children.join(',')})`;
  }

  visitTypeVec(typeVec: nodes.TypeVecNode): string {
    const child = typeVec.itemType.accept(this);
    return `vec(${child})`;
  }
}

==> kinobi-0.1.1.tgz: package/src/visitors/aggregators/GetNodeInlineStringVisitor.ts <==
import type * as nodes from '../../nodes';
import { Visitor } from '../Visitor';

const ROOT_PREFIX = 'R';
const PROGRAM_PREFIX = 'P';
const ACCOUNT_PREFIX = 'A';
const INSTRUCTION_PREFIX = 'I';
const TYPE_PREFIX = 'T';
const ERROR_PREFIX = 'E';

export class GetNodeInlineStringVisitor implements Visitor<string> {
  visitRoot(root: nodes.RootNode): string {
    const children = root.programs.map((program) => program.accept(this));
    return `${ROOT_PREFIX}(${children.join(',')})`;
  }

  visitProgram(program: nodes.ProgramNode): string {
    const children = [
      ...program.accounts.map((account) => account.accept(this)),
      ...program.instructionsWithSubs.map((ix) => ix.accept(this)),
      ...program.definedTypes.map((type) => type.accept(this)),
      ...program.errors.map((type) => type.accept(this)),
    ];
    return `${PROGRAM_PREFIX}[${program.name}](${children.join(',')})`;
  }

  visitAccount(account: nodes.AccountNode): string {
    const child = account.type.accept(this);
    return `${ACCOUNT_PREFIX}[${account.name}](${child})`;
  }

  visitInstruction(instruction: nodes.InstructionNode): string {
    const accounts = instruction.accounts.map((account) => account.name);
    const args = instruction.args.accept(this);
    return (
      `${INSTRUCTION_PREFIX}[${instruction.name}](` +
      `accounts:(${accounts.join(',')}),` +
      `args:(${args})` +
      `)`
    );
  }

  visitDefinedType(definedType: nodes.DefinedTypeNode): string {
    const child = definedType.type.accept(this);
    return `${TYPE_PREFIX}[${definedType.name}](${child})`;
  }

  visitError(error: nodes.ErrorNode): string {
    return `${ERROR_PREFIX}[${error.name}]`;
  }

  visitTypeArray(typeArray: nodes.TypeArrayNode): string {
    const child = typeArray.itemType.accept(this);
    return `array(${typeArray.size};${child})`;
  }

  visitTypeDefinedLink(typeDefinedLink: nodes.TypeDefinedLinkNode): string {
    return `link(${typeDefinedLink.definedType})`;
  }

  visitTypeEnum(typeEnum: nodes.TypeEnumNode): string {
    const children = typeEnum.variants.map((variant) => variant.accept(this));
    return `enum[${typeEnum.name}](${children.join(',')})`;
  }

  visitTypeEnumEmptyVariant(
    typeEnumEmptyVariant: nodes.TypeEnumEmptyVariantNode
  ): string {
    return typeEnumEmptyVariant.name;
  }

  visitTypeEnumStructVariant(
    typeEnumStructVariant: nodes.TypeEnumStructVariantNode
  ): string {
    const child = typeEnumStructVariant.struct.accept(this);
    return `${typeEnumStructVariant.name}:${child}`;
  }

  visitTypeEnumTupleVariant(
    typeEnumTupleVariant: nodes.TypeEnumTupleVariantNode
  ): string {
    const child = typeEnumTupleVariant.tuple.accept(this);
    return `${typeEnumTupleVariant.name}:${child}`;
  }

  visitTypeLeaf(typeLeaf: nodes.TypeLeafNode): string {
    return typeLeaf.toString();
  }

  visitTypeLeafWrapper(typeLeafWrapper: nodes.TypeLeafWrapperNode): string {
    const child = typeLeafWrapper.leaf.accept(this);
    const { wrapper } = typeLeafWrapper;
    switch (wrapper.kind) {
      case 'DateTime':
        return `DateTime(${child})`;
      case 'Amount':
        return `Amount(${child},${wrapper.identifier},${wrapper.decimals})`;
      default:
        return child;
    }
  }

  visitTypeMap(typeMap: nodes.TypeMapNode): string {
    const key = typeMap.keyType.accept(this);
    const value = typeMap.valueType.accept(this);
    return `map(${key},${value})`;
  }

  visitTypeOption(typeOption: nodes.TypeOptionNode): string {
    const child = typeOption.type.accept(this);
    return `option(${child})`;
  }

  visitTypeSet(typeSet: nodes.TypeSetNode): string {
    const child = typeSet.type.accept(this);
    return `set(${child})`;
  }

  visitTypeStruct(typeStruct: nodes.TypeStructNode): string {
    const children = typeStruct.fields.map((field) => field.accept(this));
    return `struct[${typeStruct.name}](${children.join(',')})`;
  }

  visitTypeStructField(typeStructField: nodes.TypeStructFieldNode): string {
    const child = typeStructField.type.accept(this);
    return `${typeStructField.name}:${child}`;
  }

  visitTypeTuple(typeTuple: nodes.TypeTupleNode): string {
    const children = typeTuple.itemTypes.map((itemType) =>
      itemType.accept(this)
    );
    return `tuple(${children.join(',')})`;
  }

  visitTypeVec(typeVec: nodes.TypeVecNode): string {
    const child = typeVec.itemType.accept(this);
    return `vec(${child})`;
  }
}
